@@ -7,14 +7,7 @@
  * modification of this software and in all copies of the supporting
  * documentation for such software.
  *
- * This software is subject to United States export controls.  You may
- * not export it, in whole or in part, or cause or allow such export,
- * through act or omission, without prior authorization from the United
- * States government and written permission from AT&T.  In particular,
- * you may not make any part of this software available for general or
- * unrestricted distribution to others, nor may you disclose this software
- * to persons other than citizens and permanent residents of the United
- * States and Canada. 
+ * This software is subject to United States export controls.
  *
  * THIS SOFTWARE IS BEING PROVIDED "AS IS", WITHOUT ANY EXPRESS OR IMPLIED
  * WARRANTY.  IN PARTICULAR, NEITHER THE AUTHORS NOR AT&T MAKE ANY
@@ -32,7 +25,7 @@
 cipher(k,s,d)
      cfskey *k;
      unsigned char *s;
-     int d;
+     int d; /* "decrypting" flag */
 {
 	d=d&1;
 	switch (k->cipher) {
@@ -44,20 +37,29 @@ cipher(k,s,d)
 		des_block_cipher(k->var.des3.primary2,s,1-d);
 		des_block_cipher(k->var.des3.primary1,s,d);
 		break;
+	    case TRUE_THREE_DES:
+		if (d) {
+			des_block_cipher(k->var.dest3.primary3,s,1);
+			des_block_cipher(k->var.dest3.primary2,s,1);
+			des_block_cipher(k->var.dest3.primary1,s,1);
+		} else {
+			des_block_cipher(k->var.dest3.primary1,s,0);
+			des_block_cipher(k->var.dest3.primary2,s,0);
+			des_block_cipher(k->var.dest3.primary3,s,0);
+		}
+		break;
 	    case MCG:
 		if (d)
 			mcg_block_decrypt(s,&k->var.mcg.primary);
 		else
 			mcg_block_encrypt(s,&k->var.mcg.primary);
 		break;
-#ifdef NOTDEF		
 	    case BLOWFISH:
 		if (d)
-			Blowfish_decipher(s,&k->var.bf.primary);
+			BF_encrypt(s,&k->var.bf.primary,BF_DECRYPT);
 		else
-			Blowfish_encipher(s,&k->var.bf.primary);
+			BF_encrypt(s,&k->var.bf.primary,BF_ENCRYPT);
 		break;
-#endif		
 	    case SAFER_SK128:
 		if (d)
 			Safer_Decrypt_Block(s,k->var.safer.primary,s);
@@ -83,20 +85,29 @@ mask_cipher(k,s,d)
 		des_block_cipher(k->var.des3.secondary2,s,1-d);
 		des_block_cipher(k->var.des3.secondary1,s,d);
 		break;
+	    case TRUE_THREE_DES:
+		if (d) {
+			des_block_cipher(k->var.dest3.secondary3,s,1);
+			des_block_cipher(k->var.dest3.secondary2,s,1);
+			des_block_cipher(k->var.dest3.secondary1,s,1);
+		} else {
+			des_block_cipher(k->var.dest3.secondary1,s,0);
+			des_block_cipher(k->var.dest3.secondary2,s,0);
+			des_block_cipher(k->var.dest3.secondary3,s,0);
+		}
+		break;
 	    case MCG:
 		if (d)
 			mcg_block_decrypt(s,&k->var.mcg.secondary);
 		else
 			mcg_block_encrypt(s,&k->var.mcg.secondary);
 		break;
-#ifdef NOTDEF		
 	    case BLOWFISH:
 		if (d)
-			Blowfish_decipher(s,&k->var.bf.secondary);
+			BF_encrypt(s,&k->var.bf.secondary,BF_DECRYPT);
 		else
-			Blowfish_encipher(s,&k->var.bf.secondary);
+			BF_encrypt(s,&k->var.bf.secondary,BF_ENCRYPT);
 		break;
-#endif		
 	    case SAFER_SK128:
 		if (d)
 			Safer_Decrypt_Block(s,k->var.safer.secondary,s);
@@ -132,6 +143,21 @@ copykey(key,k)
 		des_key_setup(key->cfs_admkey_u.des3key.secondary2,
 		      k->var.des3.secondary2);
 		break;
+	    case CFS_TRUE_THREE_DES:
+		k->cipher=TRUE_THREE_DES;
+		des_key_setup(key->cfs_admkey_u.tdes3key.primary1,
+		      k->var.dest3.primary1);
+		des_key_setup(key->cfs_admkey_u.tdes3key.primary2,
+		      k->var.dest3.primary2);
+		des_key_setup(key->cfs_admkey_u.tdes3key.primary3,
+		      k->var.dest3.primary3);
+		des_key_setup(key->cfs_admkey_u.tdes3key.secondary1,
+		      k->var.dest3.secondary1);
+		des_key_setup(key->cfs_admkey_u.tdes3key.secondary2,
+		      k->var.dest3.secondary2);
+		des_key_setup(key->cfs_admkey_u.tdes3key.secondary3,
+		      k->var.dest3.secondary3);
+		break;
 	    case CFS_MACGUFFIN:
 		k->cipher=MCG;
 		mcg_keyset(key->cfs_admkey_u.mcgkey.primary,
@@ -139,15 +165,13 @@ copykey(key,k)
 		mcg_keyset(key->cfs_admkey_u.mcgkey.secondary,
 			   &k->var.mcg.secondary);
 		break;
-#ifdef NOTDEF		
 	    case CFS_BLOWFISH:
 		k->cipher=BLOWFISH;
-		Blowfish_Initialize(key->cfs_admkey_u.blowkey.primary,16,
-				    &k->var.bf.primary);
-		Blowfish_Initialize(key->cfs_admkey_u.blowkey.secondary,16,
-				    &k->var.bf.secondary);
+		BF_set_key(&k->var.bf.primary,16,
+			   key->cfs_admkey_u.blowkey.primary);
+		BF_set_key(&k->var.bf.secondary,16,
+			   key->cfs_admkey_u.blowkey.secondary);
 		break;
-#endif		
 	    case CFS_SAFER_SK128:
 		k->cipher=SAFER_SK128;
 		Safer_Init_Module();
