@@ -16,7 +16,7 @@
  */
 
 /*
- * cfs file handle support - 1.2
+ * cfs file handle support - 1.4
  *  local file system interface
  */
 
@@ -98,7 +98,7 @@ readblock(blk,fd,offset,len,key,vect)
 	/* now begin and totlen are what we do the actual i/o on */
 	if (totlen>8208)
 		return -1;	/* shouldn't happen */
-	if (lseek(fd,begin,L_SET)<0)
+	if (lseek(fd,(off_t)begin,L_SET)<0)
 		return -1;
 	/* note that we are violating standard unix semantics here - we have
 	   no way to distinguish between zeros in the encrypted file and
@@ -155,7 +155,7 @@ writeblock(blk,fd,offset,len,key,vect)
 			/* we could reduce the size of this read to just
 			   the CFSBLOCKs at the head &/| tail of the file,
 			   but that's probably more trouble than it's worth.*/
-		if (lseek(fd,begin,L_SET)<0)
+		if (lseek(fd,(off_t)begin,L_SET)<0)
 			return -1;
 		/* the extra CFSBLOCK ensures that next block is ok */
 		iolen=isbndry(totlen)?totlen:(totlen+CFSBLOCK);
@@ -167,7 +167,7 @@ writeblock(blk,fd,offset,len,key,vect)
 	/* now we can do the actual encrypt and i/o */
 	bcopy((char *)blk,(char *)(buf+fronterr),len);
 	doencrypt(key,buf,totlen,begin,vect);
-	if (lseek(fd,begin,L_SET)<0)
+	if (lseek(fd,(off_t)begin,L_SET)<0)
 		return -1;
 	/* again, holes in the file are a delicate problem.  If the CFSBLOCK
 	   bountry is not always on a file boundry, you could even corrupt
@@ -362,7 +362,11 @@ static fh_u roothandle;
 cfs_fileid rootnode={1,0,"\0\0\0\0\0\0\0\0","/NOWHERE/null",NULL,NULL,0,NULL,NULL};/* fileid=1; should be unique */
 nfstime roottime={0,0};
 
-static u_char magictest[8]={0x01,0x23,0x45,0x67,0x89,0xab,0xcd,0xef};
+/* Had to change this - someone else was using the same magic number! */
+/* PLEASE change this value if you're going to re-use this code for
+/* something else!  Otherwise your FS and CFS can't both run... */
+/* static u_char magictest[8]={0x01,0x23,0x45,0x67,0x89,0xab,0xcd,0xef}; */
+static u_char magictest[8]="M.Blaze";
 
 static cfs_fileid *
 findh(id,ins
